CVS: plexus-components/formica/src/java/org/codehaus/plexus/formica/validation/group AbstractGroupValidator.java,1.1.1.1,1.2

[email protected] Sun, 1 Jun 2003 15:55:03 -0500
Newsgroups gmane.comp.java.plexus.devel
Message-ID <[email protected]>
Update of /cvsroot/plexus/plexus-components/formica/src/java/org/codehaus/plexus/formica/validation/group
In directory eng.werken.com:/tmp/cvs-serv8457/src/java/org/codehaus/plexus/formica/validation/group

Modified Files:
	AbstractGroupValidator.java 
Log Message:
o Switching over to using messageKey and labelKey so that I can use a message
  store of some sort to take into account localization.


Index: AbstractGroupValidator.java
===================================================================
RCS file: /cvsroot/plexus/plexus-components/formica/src/java/org/codehaus/plexus/formica/validation/group/AbstractGroupValidator.java,v
retrieving revision 1.1.1.1
retrieving revision 1.2
diff -u -d -r1.1.1.1 -r1.2
--- AbstractGroupValidator.java	1 Jun 2003 19:12:21 -0000	1.1.1.1
+++ AbstractGroupValidator.java	1 Jun 2003 20:55:01 -0000	1.2
@@ -69,9 +69,9 @@
     protected String message;
     protected String errorMessage;
 
     /** Return the validator error message using the default Locale.
 
-     @return The error message
+     @return The error messageKey
      */
 
     public String getErrorMessage()
@@ -79,12 +79,12 @@
         return getErrorMessage( Locale.getDefault() );
     }
 
-    /** Get the validator error message for the given locale.  If
-     no error message is specified in the configuration then this
+    /** Get the validator error messageKey for the given locale.  If
+     no error messageKey is specified in the configuration then this
      method returns null.
 
      @param locale The locale
-     @return The error message
+     @return The error messageKey
      */
 
     public String getErrorMessage( Locale locale )
@@ -69,9 +69,9 @@
     protected String errorMessage;
 
-    /** Return the validator error message using the default Locale.
+    /** Return the validator error messageKey using the default Locale.
 